# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDatabaseInsightsResult',
    'AwaitableGetDatabaseInsightsResult',
    'get_database_insights',
    'get_database_insights_output',
]

@pulumi.output_type
class GetDatabaseInsightsResult:
    """
    A collection of values returned by getDatabaseInsights.
    """
    def __init__(__self__, compartment_id=None, compartment_id_in_subtree=None, database_ids=None, database_insights_collections=None, database_types=None, enterprise_manager_bridge_id=None, exadata_insight_id=None, fields=None, filters=None, id=None, opsi_private_endpoint_id=None, states=None, statuses=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compartment_id_in_subtree and not isinstance(compartment_id_in_subtree, bool):
            raise TypeError("Expected argument 'compartment_id_in_subtree' to be a bool")
        pulumi.set(__self__, "compartment_id_in_subtree", compartment_id_in_subtree)
        if database_ids and not isinstance(database_ids, list):
            raise TypeError("Expected argument 'database_ids' to be a list")
        pulumi.set(__self__, "database_ids", database_ids)
        if database_insights_collections and not isinstance(database_insights_collections, list):
            raise TypeError("Expected argument 'database_insights_collections' to be a list")
        pulumi.set(__self__, "database_insights_collections", database_insights_collections)
        if database_types and not isinstance(database_types, list):
            raise TypeError("Expected argument 'database_types' to be a list")
        pulumi.set(__self__, "database_types", database_types)
        if enterprise_manager_bridge_id and not isinstance(enterprise_manager_bridge_id, str):
            raise TypeError("Expected argument 'enterprise_manager_bridge_id' to be a str")
        pulumi.set(__self__, "enterprise_manager_bridge_id", enterprise_manager_bridge_id)
        if exadata_insight_id and not isinstance(exadata_insight_id, str):
            raise TypeError("Expected argument 'exadata_insight_id' to be a str")
        pulumi.set(__self__, "exadata_insight_id", exadata_insight_id)
        if fields and not isinstance(fields, list):
            raise TypeError("Expected argument 'fields' to be a list")
        pulumi.set(__self__, "fields", fields)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if opsi_private_endpoint_id and not isinstance(opsi_private_endpoint_id, str):
            raise TypeError("Expected argument 'opsi_private_endpoint_id' to be a str")
        pulumi.set(__self__, "opsi_private_endpoint_id", opsi_private_endpoint_id)
        if states and not isinstance(states, list):
            raise TypeError("Expected argument 'states' to be a list")
        pulumi.set(__self__, "states", states)
        if statuses and not isinstance(statuses, list):
            raise TypeError("Expected argument 'statuses' to be a list")
        pulumi.set(__self__, "statuses", statuses)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[str]:
        """
        Compartment identifier of the database
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="compartmentIdInSubtree")
    def compartment_id_in_subtree(self) -> Optional[bool]:
        return pulumi.get(self, "compartment_id_in_subtree")

    @property
    @pulumi.getter(name="databaseIds")
    def database_ids(self) -> Optional[Sequence[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
        """
        return pulumi.get(self, "database_ids")

    @property
    @pulumi.getter(name="databaseInsightsCollections")
    def database_insights_collections(self) -> Sequence['outputs.GetDatabaseInsightsDatabaseInsightsCollectionResult']:
        """
        The list of database_insights_collection.
        """
        return pulumi.get(self, "database_insights_collections")

    @property
    @pulumi.getter(name="databaseTypes")
    def database_types(self) -> Optional[Sequence[str]]:
        """
        Operations Insights internal representation of the database type.
        """
        return pulumi.get(self, "database_types")

    @property
    @pulumi.getter(name="enterpriseManagerBridgeId")
    def enterprise_manager_bridge_id(self) -> Optional[str]:
        """
        OPSI Enterprise Manager Bridge OCID
        """
        return pulumi.get(self, "enterprise_manager_bridge_id")

    @property
    @pulumi.getter(name="exadataInsightId")
    def exadata_insight_id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
        """
        return pulumi.get(self, "exadata_insight_id")

    @property
    @pulumi.getter
    def fields(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "fields")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetDatabaseInsightsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        Database insight identifier
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="opsiPrivateEndpointId")
    def opsi_private_endpoint_id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the OPSI private endpoint
        """
        return pulumi.get(self, "opsi_private_endpoint_id")

    @property
    @pulumi.getter
    def states(self) -> Optional[Sequence[str]]:
        """
        The current state of the database.
        """
        return pulumi.get(self, "states")

    @property
    @pulumi.getter
    def statuses(self) -> Optional[Sequence[str]]:
        """
        Indicates the status of a database insight in Operations Insights
        """
        return pulumi.get(self, "statuses")


class AwaitableGetDatabaseInsightsResult(GetDatabaseInsightsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseInsightsResult(
            compartment_id=self.compartment_id,
            compartment_id_in_subtree=self.compartment_id_in_subtree,
            database_ids=self.database_ids,
            database_insights_collections=self.database_insights_collections,
            database_types=self.database_types,
            enterprise_manager_bridge_id=self.enterprise_manager_bridge_id,
            exadata_insight_id=self.exadata_insight_id,
            fields=self.fields,
            filters=self.filters,
            id=self.id,
            opsi_private_endpoint_id=self.opsi_private_endpoint_id,
            states=self.states,
            statuses=self.statuses)


def get_database_insights(compartment_id: Optional[str] = None,
                          compartment_id_in_subtree: Optional[bool] = None,
                          database_ids: Optional[Sequence[str]] = None,
                          database_types: Optional[Sequence[str]] = None,
                          enterprise_manager_bridge_id: Optional[str] = None,
                          exadata_insight_id: Optional[str] = None,
                          fields: Optional[Sequence[str]] = None,
                          filters: Optional[Sequence[pulumi.InputType['GetDatabaseInsightsFilterArgs']]] = None,
                          id: Optional[str] = None,
                          opsi_private_endpoint_id: Optional[str] = None,
                          states: Optional[Sequence[str]] = None,
                          statuses: Optional[Sequence[str]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseInsightsResult:
    """
    This data source provides the list of Database Insights in Oracle Cloud Infrastructure Opsi service.

    Gets a list of database insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
    When both compartmentId and compartmentIdInSubtree are specified, a list of database insights in that compartment and in all sub-compartments will be returned.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_database_insights = oci.Opsi.get_database_insights(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        database_ids=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        database_types=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        enterprise_manager_bridge_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        exadata_insight_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        fields=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        opsi_private_endpoint_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        states=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        statuses=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param bool compartment_id_in_subtree: A flag to search all resources within a given compartment and all sub-compartments.
    :param Sequence[str] database_ids: Optional list of database [OCIDs](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the associated DBaaS entity.
    :param Sequence[str] database_types: Filter by one or more database type. Possible values are ADW-S, ATP-S, ADW-D, ATP-D, EXTERNAL-PDB, EXTERNAL-NONCDB.
    :param str enterprise_manager_bridge_id: Unique Enterprise Manager bridge identifier
    :param str exadata_insight_id: [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of exadata insight resource.
    :param Sequence[str] fields: Specifies the fields to return in a database summary response. By default all fields are returned if omitted.
    :param str id: Optional list of database insight resource [OCIDs](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str opsi_private_endpoint_id: Unique Operations Insights PrivateEndpoint identifier
    :param Sequence[str] states: Lifecycle states
    :param Sequence[str] statuses: Resource Status
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['compartmentIdInSubtree'] = compartment_id_in_subtree
    __args__['databaseIds'] = database_ids
    __args__['databaseTypes'] = database_types
    __args__['enterpriseManagerBridgeId'] = enterprise_manager_bridge_id
    __args__['exadataInsightId'] = exadata_insight_id
    __args__['fields'] = fields
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['opsiPrivateEndpointId'] = opsi_private_endpoint_id
    __args__['states'] = states
    __args__['statuses'] = statuses
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Opsi/getDatabaseInsights:getDatabaseInsights', __args__, opts=opts, typ=GetDatabaseInsightsResult).value

    return AwaitableGetDatabaseInsightsResult(
        compartment_id=__ret__.compartment_id,
        compartment_id_in_subtree=__ret__.compartment_id_in_subtree,
        database_ids=__ret__.database_ids,
        database_insights_collections=__ret__.database_insights_collections,
        database_types=__ret__.database_types,
        enterprise_manager_bridge_id=__ret__.enterprise_manager_bridge_id,
        exadata_insight_id=__ret__.exadata_insight_id,
        fields=__ret__.fields,
        filters=__ret__.filters,
        id=__ret__.id,
        opsi_private_endpoint_id=__ret__.opsi_private_endpoint_id,
        states=__ret__.states,
        statuses=__ret__.statuses)


@_utilities.lift_output_func(get_database_insights)
def get_database_insights_output(compartment_id: Optional[pulumi.Input[Optional[str]]] = None,
                                 compartment_id_in_subtree: Optional[pulumi.Input[Optional[bool]]] = None,
                                 database_ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                 database_types: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                 enterprise_manager_bridge_id: Optional[pulumi.Input[Optional[str]]] = None,
                                 exadata_insight_id: Optional[pulumi.Input[Optional[str]]] = None,
                                 fields: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                 filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetDatabaseInsightsFilterArgs']]]]] = None,
                                 id: Optional[pulumi.Input[Optional[str]]] = None,
                                 opsi_private_endpoint_id: Optional[pulumi.Input[Optional[str]]] = None,
                                 states: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                 statuses: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDatabaseInsightsResult]:
    """
    This data source provides the list of Database Insights in Oracle Cloud Infrastructure Opsi service.

    Gets a list of database insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
    When both compartmentId and compartmentIdInSubtree are specified, a list of database insights in that compartment and in all sub-compartments will be returned.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_database_insights = oci.Opsi.get_database_insights(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        database_ids=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        database_types=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        enterprise_manager_bridge_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        exadata_insight_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        fields=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        opsi_private_endpoint_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        states=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        statuses=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param bool compartment_id_in_subtree: A flag to search all resources within a given compartment and all sub-compartments.
    :param Sequence[str] database_ids: Optional list of database [OCIDs](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the associated DBaaS entity.
    :param Sequence[str] database_types: Filter by one or more database type. Possible values are ADW-S, ATP-S, ADW-D, ATP-D, EXTERNAL-PDB, EXTERNAL-NONCDB.
    :param str enterprise_manager_bridge_id: Unique Enterprise Manager bridge identifier
    :param str exadata_insight_id: [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of exadata insight resource.
    :param Sequence[str] fields: Specifies the fields to return in a database summary response. By default all fields are returned if omitted.
    :param str id: Optional list of database insight resource [OCIDs](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str opsi_private_endpoint_id: Unique Operations Insights PrivateEndpoint identifier
    :param Sequence[str] states: Lifecycle states
    :param Sequence[str] statuses: Resource Status
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetScheduledRunsResult',
    'AwaitableGetScheduledRunsResult',
    'get_scheduled_runs',
    'get_scheduled_runs_output',
]

@pulumi.output_type
class GetScheduledRunsResult:
    """
    A collection of values returned by getScheduledRuns.
    """
    def __init__(__self__, filters=None, id=None, schedule_id=None, scheduled_run_collections=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if schedule_id and not isinstance(schedule_id, str):
            raise TypeError("Expected argument 'schedule_id' to be a str")
        pulumi.set(__self__, "schedule_id", schedule_id)
        if scheduled_run_collections and not isinstance(scheduled_run_collections, list):
            raise TypeError("Expected argument 'scheduled_run_collections' to be a list")
        pulumi.set(__self__, "scheduled_run_collections", scheduled_run_collections)

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetScheduledRunsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="scheduleId")
    def schedule_id(self) -> str:
        """
        The ocid representing unique shedule
        """
        return pulumi.get(self, "schedule_id")

    @property
    @pulumi.getter(name="scheduledRunCollections")
    def scheduled_run_collections(self) -> Sequence['outputs.GetScheduledRunsScheduledRunCollectionResult']:
        """
        The list of scheduled_run_collection.
        """
        return pulumi.get(self, "scheduled_run_collections")


class AwaitableGetScheduledRunsResult(GetScheduledRunsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetScheduledRunsResult(
            filters=self.filters,
            id=self.id,
            schedule_id=self.schedule_id,
            scheduled_run_collections=self.scheduled_run_collections)


def get_scheduled_runs(filters: Optional[Sequence[pulumi.InputType['GetScheduledRunsFilterArgs']]] = None,
                       schedule_id: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetScheduledRunsResult:
    """
    This data source provides the list of Scheduled Runs in Oracle Cloud Infrastructure Metering Computation service.

    Returns schedule history list.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_scheduled_runs = oci.MeteringComputation.get_scheduled_runs(schedule_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str schedule_id: The unique ID of a schedule.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['scheduleId'] = schedule_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:MeteringComputation/getScheduledRuns:getScheduledRuns', __args__, opts=opts, typ=GetScheduledRunsResult).value

    return AwaitableGetScheduledRunsResult(
        filters=__ret__.filters,
        id=__ret__.id,
        schedule_id=__ret__.schedule_id,
        scheduled_run_collections=__ret__.scheduled_run_collections)


@_utilities.lift_output_func(get_scheduled_runs)
def get_scheduled_runs_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetScheduledRunsFilterArgs']]]]] = None,
                              schedule_id: Optional[pulumi.Input[str]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetScheduledRunsResult]:
    """
    This data source provides the list of Scheduled Runs in Oracle Cloud Infrastructure Metering Computation service.

    Returns schedule history list.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_scheduled_runs = oci.MeteringComputation.get_scheduled_runs(schedule_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str schedule_id: The unique ID of a schedule.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAuditArchiveRetrievalsResult',
    'AwaitableGetAuditArchiveRetrievalsResult',
    'get_audit_archive_retrievals',
    'get_audit_archive_retrievals_output',
]

@pulumi.output_type
class GetAuditArchiveRetrievalsResult:
    """
    A collection of values returned by getAuditArchiveRetrievals.
    """
    def __init__(__self__, access_level=None, audit_archive_retrieval_collections=None, audit_archive_retrieval_id=None, compartment_id=None, compartment_id_in_subtree=None, display_name=None, filters=None, id=None, state=None, target_id=None, time_of_expiry=None):
        if access_level and not isinstance(access_level, str):
            raise TypeError("Expected argument 'access_level' to be a str")
        pulumi.set(__self__, "access_level", access_level)
        if audit_archive_retrieval_collections and not isinstance(audit_archive_retrieval_collections, list):
            raise TypeError("Expected argument 'audit_archive_retrieval_collections' to be a list")
        pulumi.set(__self__, "audit_archive_retrieval_collections", audit_archive_retrieval_collections)
        if audit_archive_retrieval_id and not isinstance(audit_archive_retrieval_id, str):
            raise TypeError("Expected argument 'audit_archive_retrieval_id' to be a str")
        pulumi.set(__self__, "audit_archive_retrieval_id", audit_archive_retrieval_id)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compartment_id_in_subtree and not isinstance(compartment_id_in_subtree, bool):
            raise TypeError("Expected argument 'compartment_id_in_subtree' to be a bool")
        pulumi.set(__self__, "compartment_id_in_subtree", compartment_id_in_subtree)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if target_id and not isinstance(target_id, str):
            raise TypeError("Expected argument 'target_id' to be a str")
        pulumi.set(__self__, "target_id", target_id)
        if time_of_expiry and not isinstance(time_of_expiry, str):
            raise TypeError("Expected argument 'time_of_expiry' to be a str")
        pulumi.set(__self__, "time_of_expiry", time_of_expiry)

    @property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[str]:
        return pulumi.get(self, "access_level")

    @property
    @pulumi.getter(name="auditArchiveRetrievalCollections")
    def audit_archive_retrieval_collections(self) -> Sequence['outputs.GetAuditArchiveRetrievalsAuditArchiveRetrievalCollectionResult']:
        """
        The list of audit_archive_retrieval_collection.
        """
        return pulumi.get(self, "audit_archive_retrieval_collections")

    @property
    @pulumi.getter(name="auditArchiveRetrievalId")
    def audit_archive_retrieval_id(self) -> Optional[str]:
        return pulumi.get(self, "audit_archive_retrieval_id")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment that contains archive retrieval.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="compartmentIdInSubtree")
    def compartment_id_in_subtree(self) -> Optional[bool]:
        return pulumi.get(self, "compartment_id_in_subtree")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The display name of the archive retrieval. The name does not have to be unique, and is changeable.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAuditArchiveRetrievalsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the archive retrieval.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="targetId")
    def target_id(self) -> Optional[str]:
        """
        The OCID of the target associated with the archive retrieval.
        """
        return pulumi.get(self, "target_id")

    @property
    @pulumi.getter(name="timeOfExpiry")
    def time_of_expiry(self) -> Optional[str]:
        """
        The date time when retrieved archive data will be deleted from Data Safe and unloaded back into archival.
        """
        return pulumi.get(self, "time_of_expiry")


class AwaitableGetAuditArchiveRetrievalsResult(GetAuditArchiveRetrievalsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuditArchiveRetrievalsResult(
            access_level=self.access_level,
            audit_archive_retrieval_collections=self.audit_archive_retrieval_collections,
            audit_archive_retrieval_id=self.audit_archive_retrieval_id,
            compartment_id=self.compartment_id,
            compartment_id_in_subtree=self.compartment_id_in_subtree,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            state=self.state,
            target_id=self.target_id,
            time_of_expiry=self.time_of_expiry)


def get_audit_archive_retrievals(access_level: Optional[str] = None,
                                 audit_archive_retrieval_id: Optional[str] = None,
                                 compartment_id: Optional[str] = None,
                                 compartment_id_in_subtree: Optional[bool] = None,
                                 display_name: Optional[str] = None,
                                 filters: Optional[Sequence[pulumi.InputType['GetAuditArchiveRetrievalsFilterArgs']]] = None,
                                 state: Optional[str] = None,
                                 target_id: Optional[str] = None,
                                 time_of_expiry: Optional[str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuditArchiveRetrievalsResult:
    """
    This data source provides the list of Audit Archive Retrievals in Oracle Cloud Infrastructure Data Safe service.

    Returns the list of audit archive retrieval.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_audit_archive_retrievals = oci.DataSafe.get_audit_archive_retrievals(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        audit_archive_retrieval_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_of_expiry=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Valid values are RESTRICTED and ACCESSIBLE. Default is RESTRICTED. Setting this to ACCESSIBLE returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment). When set to RESTRICTED permissions are checked and no partial results are displayed.
    :param str audit_archive_retrieval_id: OCID of the archive retrieval.
    :param str compartment_id: A filter to return only resources that match the specified compartment OCID.
    :param bool compartment_id_in_subtree: Default is false. When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned. Depends on the 'accessLevel' setting.
    :param str display_name: A filter to return only resources that match the specified display name.
    :param str state: A filter to return only resources that matches the specified lifecycle state.
    :param str target_id: The OCID of the target associated with the archive retrieval.
    :param str time_of_expiry: The date time when retrieved archive data will be deleted from Data Safe and unloaded back into archival.
    """
    __args__ = dict()
    __args__['accessLevel'] = access_level
    __args__['auditArchiveRetrievalId'] = audit_archive_retrieval_id
    __args__['compartmentId'] = compartment_id
    __args__['compartmentIdInSubtree'] = compartment_id_in_subtree
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['state'] = state
    __args__['targetId'] = target_id
    __args__['timeOfExpiry'] = time_of_expiry
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getAuditArchiveRetrievals:getAuditArchiveRetrievals', __args__, opts=opts, typ=GetAuditArchiveRetrievalsResult).value

    return AwaitableGetAuditArchiveRetrievalsResult(
        access_level=__ret__.access_level,
        audit_archive_retrieval_collections=__ret__.audit_archive_retrieval_collections,
        audit_archive_retrieval_id=__ret__.audit_archive_retrieval_id,
        compartment_id=__ret__.compartment_id,
        compartment_id_in_subtree=__ret__.compartment_id_in_subtree,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        state=__ret__.state,
        target_id=__ret__.target_id,
        time_of_expiry=__ret__.time_of_expiry)


@_utilities.lift_output_func(get_audit_archive_retrievals)
def get_audit_archive_retrievals_output(access_level: Optional[pulumi.Input[Optional[str]]] = None,
                                        audit_archive_retrieval_id: Optional[pulumi.Input[Optional[str]]] = None,
                                        compartment_id: Optional[pulumi.Input[str]] = None,
                                        compartment_id_in_subtree: Optional[pulumi.Input[Optional[bool]]] = None,
                                        display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                        filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAuditArchiveRetrievalsFilterArgs']]]]] = None,
                                        state: Optional[pulumi.Input[Optional[str]]] = None,
                                        target_id: Optional[pulumi.Input[Optional[str]]] = None,
                                        time_of_expiry: Optional[pulumi.Input[Optional[str]]] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAuditArchiveRetrievalsResult]:
    """
    This data source provides the list of Audit Archive Retrievals in Oracle Cloud Infrastructure Data Safe service.

    Returns the list of audit archive retrieval.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_audit_archive_retrievals = oci.DataSafe.get_audit_archive_retrievals(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        audit_archive_retrieval_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_of_expiry=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Valid values are RESTRICTED and ACCESSIBLE. Default is RESTRICTED. Setting this to ACCESSIBLE returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment). When set to RESTRICTED permissions are checked and no partial results are displayed.
    :param str audit_archive_retrieval_id: OCID of the archive retrieval.
    :param str compartment_id: A filter to return only resources that match the specified compartment OCID.
    :param bool compartment_id_in_subtree: Default is false. When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned. Depends on the 'accessLevel' setting.
    :param str display_name: A filter to return only resources that match the specified display name.
    :param str state: A filter to return only resources that matches the specified lifecycle state.
    :param str target_id: The OCID of the target associated with the archive retrieval.
    :param str time_of_expiry: The date time when retrieved archive data will be deleted from Data Safe and unloaded back into archival.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetDbHomeResult',
    'AwaitableGetDbHomeResult',
    'get_db_home',
    'get_db_home_output',
]

@pulumi.output_type
class GetDbHomeResult:
    """
    A collection of values returned by getDbHome.
    """
    def __init__(__self__, compartment_id=None, database_software_image_id=None, databases=None, db_home_id=None, db_home_location=None, db_system_id=None, db_version=None, defined_tags=None, display_name=None, enable_database_delete=None, freeform_tags=None, id=None, is_desupported_version=None, kms_key_id=None, kms_key_version_id=None, last_patch_history_entry_id=None, lifecycle_details=None, source=None, state=None, time_created=None, vm_cluster_id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if database_software_image_id and not isinstance(database_software_image_id, str):
            raise TypeError("Expected argument 'database_software_image_id' to be a str")
        pulumi.set(__self__, "database_software_image_id", database_software_image_id)
        if databases and not isinstance(databases, list):
            raise TypeError("Expected argument 'databases' to be a list")
        pulumi.set(__self__, "databases", databases)
        if db_home_id and not isinstance(db_home_id, str):
            raise TypeError("Expected argument 'db_home_id' to be a str")
        pulumi.set(__self__, "db_home_id", db_home_id)
        if db_home_location and not isinstance(db_home_location, str):
            raise TypeError("Expected argument 'db_home_location' to be a str")
        pulumi.set(__self__, "db_home_location", db_home_location)
        if db_system_id and not isinstance(db_system_id, str):
            raise TypeError("Expected argument 'db_system_id' to be a str")
        pulumi.set(__self__, "db_system_id", db_system_id)
        if db_version and not isinstance(db_version, str):
            raise TypeError("Expected argument 'db_version' to be a str")
        pulumi.set(__self__, "db_version", db_version)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if enable_database_delete and not isinstance(enable_database_delete, bool):
            raise TypeError("Expected argument 'enable_database_delete' to be a bool")
        pulumi.set(__self__, "enable_database_delete", enable_database_delete)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_desupported_version and not isinstance(is_desupported_version, bool):
            raise TypeError("Expected argument 'is_desupported_version' to be a bool")
        pulumi.set(__self__, "is_desupported_version", is_desupported_version)
        if kms_key_id and not isinstance(kms_key_id, str):
            raise TypeError("Expected argument 'kms_key_id' to be a str")
        pulumi.set(__self__, "kms_key_id", kms_key_id)
        if kms_key_version_id and not isinstance(kms_key_version_id, str):
            raise TypeError("Expected argument 'kms_key_version_id' to be a str")
        pulumi.set(__self__, "kms_key_version_id", kms_key_version_id)
        if last_patch_history_entry_id and not isinstance(last_patch_history_entry_id, str):
            raise TypeError("Expected argument 'last_patch_history_entry_id' to be a str")
        pulumi.set(__self__, "last_patch_history_entry_id", last_patch_history_entry_id)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if source and not isinstance(source, str):
            raise TypeError("Expected argument 'source' to be a str")
        pulumi.set(__self__, "source", source)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if vm_cluster_id and not isinstance(vm_cluster_id, str):
            raise TypeError("Expected argument 'vm_cluster_id' to be a str")
        pulumi.set(__self__, "vm_cluster_id", vm_cluster_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="databaseSoftwareImageId")
    def database_software_image_id(self) -> str:
        """
        The database software image [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)
        """
        return pulumi.get(self, "database_software_image_id")

    @property
    @pulumi.getter
    def databases(self) -> Sequence['outputs.GetDbHomeDatabaseResult']:
        return pulumi.get(self, "databases")

    @property
    @pulumi.getter(name="dbHomeId")
    def db_home_id(self) -> str:
        return pulumi.get(self, "db_home_id")

    @property
    @pulumi.getter(name="dbHomeLocation")
    def db_home_location(self) -> str:
        """
        The location of the Oracle Database Home.
        """
        return pulumi.get(self, "db_home_location")

    @property
    @pulumi.getter(name="dbSystemId")
    def db_system_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DB system.
        """
        return pulumi.get(self, "db_system_id")

    @property
    @pulumi.getter(name="dbVersion")
    def db_version(self) -> str:
        """
        The Oracle Database version.
        """
        return pulumi.get(self, "db_version")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The user-provided name for the Database Home. The name does not need to be unique.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="enableDatabaseDelete")
    def enable_database_delete(self) -> bool:
        return pulumi.get(self, "enable_database_delete")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Database Home.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isDesupportedVersion")
    def is_desupported_version(self) -> bool:
        return pulumi.get(self, "is_desupported_version")

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> str:
        """
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
        """
        return pulumi.get(self, "kms_key_id")

    @property
    @pulumi.getter(name="kmsKeyVersionId")
    def kms_key_version_id(self) -> str:
        return pulumi.get(self, "kms_key_version_id")

    @property
    @pulumi.getter(name="lastPatchHistoryEntryId")
    def last_patch_history_entry_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the last patch history. This value is updated as soon as a patch operation is started.
        """
        return pulumi.get(self, "last_patch_history_entry_id")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        Additional information about the current lifecycle state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter
    def source(self) -> str:
        return pulumi.get(self, "source")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the Database Home.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the Database Home was created.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="vmClusterId")
    def vm_cluster_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VM cluster.
        """
        return pulumi.get(self, "vm_cluster_id")


class AwaitableGetDbHomeResult(GetDbHomeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDbHomeResult(
            compartment_id=self.compartment_id,
            database_software_image_id=self.database_software_image_id,
            databases=self.databases,
            db_home_id=self.db_home_id,
            db_home_location=self.db_home_location,
            db_system_id=self.db_system_id,
            db_version=self.db_version,
            defined_tags=self.defined_tags,
            display_name=self.display_name,
            enable_database_delete=self.enable_database_delete,
            freeform_tags=self.freeform_tags,
            id=self.id,
            is_desupported_version=self.is_desupported_version,
            kms_key_id=self.kms_key_id,
            kms_key_version_id=self.kms_key_version_id,
            last_patch_history_entry_id=self.last_patch_history_entry_id,
            lifecycle_details=self.lifecycle_details,
            source=self.source,
            state=self.state,
            time_created=self.time_created,
            vm_cluster_id=self.vm_cluster_id)


def get_db_home(db_home_id: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDbHomeResult:
    """
    This data source provides details about a specific Db Home resource in Oracle Cloud Infrastructure Database service.

    Gets information about the specified Database Home.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_db_home = oci.Database.get_db_home(db_home_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str db_home_id: The Database Home [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    __args__ = dict()
    __args__['dbHomeId'] = db_home_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getDbHome:getDbHome', __args__, opts=opts, typ=GetDbHomeResult).value

    return AwaitableGetDbHomeResult(
        compartment_id=__ret__.compartment_id,
        database_software_image_id=__ret__.database_software_image_id,
        databases=__ret__.databases,
        db_home_id=__ret__.db_home_id,
        db_home_location=__ret__.db_home_location,
        db_system_id=__ret__.db_system_id,
        db_version=__ret__.db_version,
        defined_tags=__ret__.defined_tags,
        display_name=__ret__.display_name,
        enable_database_delete=__ret__.enable_database_delete,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        is_desupported_version=__ret__.is_desupported_version,
        kms_key_id=__ret__.kms_key_id,
        kms_key_version_id=__ret__.kms_key_version_id,
        last_patch_history_entry_id=__ret__.last_patch_history_entry_id,
        lifecycle_details=__ret__.lifecycle_details,
        source=__ret__.source,
        state=__ret__.state,
        time_created=__ret__.time_created,
        vm_cluster_id=__ret__.vm_cluster_id)


@_utilities.lift_output_func(get_db_home)
def get_db_home_output(db_home_id: Optional[pulumi.Input[str]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDbHomeResult]:
    """
    This data source provides details about a specific Db Home resource in Oracle Cloud Infrastructure Database service.

    Gets information about the specified Database Home.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_db_home = oci.Database.get_db_home(db_home_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str db_home_id: The Database Home [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetImageShapeResult',
    'AwaitableGetImageShapeResult',
    'get_image_shape',
    'get_image_shape_output',
]

@pulumi.output_type
class GetImageShapeResult:
    """
    A collection of values returned by getImageShape.
    """
    def __init__(__self__, id=None, image_id=None, memory_constraints=None, ocpu_constraints=None, shape=None, shape_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if memory_constraints and not isinstance(memory_constraints, list):
            raise TypeError("Expected argument 'memory_constraints' to be a list")
        pulumi.set(__self__, "memory_constraints", memory_constraints)
        if ocpu_constraints and not isinstance(ocpu_constraints, list):
            raise TypeError("Expected argument 'ocpu_constraints' to be a list")
        pulumi.set(__self__, "ocpu_constraints", ocpu_constraints)
        if shape and not isinstance(shape, str):
            raise TypeError("Expected argument 'shape' to be a str")
        pulumi.set(__self__, "shape", shape)
        if shape_name and not isinstance(shape_name, str):
            raise TypeError("Expected argument 'shape_name' to be a str")
        pulumi.set(__self__, "shape_name", shape_name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> str:
        """
        The image [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="memoryConstraints")
    def memory_constraints(self) -> Sequence['outputs.GetImageShapeMemoryConstraintResult']:
        """
        For a flexible image and shape, the amount of memory supported for instances that use this image.
        """
        return pulumi.get(self, "memory_constraints")

    @property
    @pulumi.getter(name="ocpuConstraints")
    def ocpu_constraints(self) -> Sequence['outputs.GetImageShapeOcpuConstraintResult']:
        """
        OCPU options for an image and shape.
        """
        return pulumi.get(self, "ocpu_constraints")

    @property
    @pulumi.getter
    def shape(self) -> str:
        """
        The shape name.
        """
        return pulumi.get(self, "shape")

    @property
    @pulumi.getter(name="shapeName")
    def shape_name(self) -> str:
        return pulumi.get(self, "shape_name")


class AwaitableGetImageShapeResult(GetImageShapeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetImageShapeResult(
            id=self.id,
            image_id=self.image_id,
            memory_constraints=self.memory_constraints,
            ocpu_constraints=self.ocpu_constraints,
            shape=self.shape,
            shape_name=self.shape_name)


def get_image_shape(image_id: Optional[str] = None,
                    shape_name: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetImageShapeResult:
    """
    This data source provides details about a specific Image Shape resource in Oracle Cloud Infrastructure Core service.

    Retrieves an image shape compatibility entry.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_image_shape = oci.Core.get_image_shape(image_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        shape_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str image_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the image.
    :param str shape_name: Shape name.
    """
    __args__ = dict()
    __args__['imageId'] = image_id
    __args__['shapeName'] = shape_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getImageShape:getImageShape', __args__, opts=opts, typ=GetImageShapeResult).value

    return AwaitableGetImageShapeResult(
        id=__ret__.id,
        image_id=__ret__.image_id,
        memory_constraints=__ret__.memory_constraints,
        ocpu_constraints=__ret__.ocpu_constraints,
        shape=__ret__.shape,
        shape_name=__ret__.shape_name)


@_utilities.lift_output_func(get_image_shape)
def get_image_shape_output(image_id: Optional[pulumi.Input[str]] = None,
                           shape_name: Optional[pulumi.Input[str]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetImageShapeResult]:
    """
    This data source provides details about a specific Image Shape resource in Oracle Cloud Infrastructure Core service.

    Retrieves an image shape compatibility entry.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_image_shape = oci.Core.get_image_shape(image_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        shape_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str image_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the image.
    :param str shape_name: Shape name.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceMeasuredBootReportResult',
    'AwaitableGetInstanceMeasuredBootReportResult',
    'get_instance_measured_boot_report',
    'get_instance_measured_boot_report_output',
]

@pulumi.output_type
class GetInstanceMeasuredBootReportResult:
    """
    A collection of values returned by getInstanceMeasuredBootReport.
    """
    def __init__(__self__, id=None, instance_id=None, is_policy_verification_successful=None, measurements=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if is_policy_verification_successful and not isinstance(is_policy_verification_successful, bool):
            raise TypeError("Expected argument 'is_policy_verification_successful' to be a bool")
        pulumi.set(__self__, "is_policy_verification_successful", is_policy_verification_successful)
        if measurements and not isinstance(measurements, list):
            raise TypeError("Expected argument 'measurements' to be a list")
        pulumi.set(__self__, "measurements", measurements)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="isPolicyVerificationSuccessful")
    def is_policy_verification_successful(self) -> bool:
        """
        Whether the verification succeeded, and the new values match the expected values.
        """
        return pulumi.get(self, "is_policy_verification_successful")

    @property
    @pulumi.getter
    def measurements(self) -> Sequence['outputs.GetInstanceMeasuredBootReportMeasurementResult']:
        """
        A list of Trusted Platform Module (TPM) Platform Configuration Register (PCR) entries.
        """
        return pulumi.get(self, "measurements")


class AwaitableGetInstanceMeasuredBootReportResult(GetInstanceMeasuredBootReportResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceMeasuredBootReportResult(
            id=self.id,
            instance_id=self.instance_id,
            is_policy_verification_successful=self.is_policy_verification_successful,
            measurements=self.measurements)


def get_instance_measured_boot_report(instance_id: Optional[str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceMeasuredBootReportResult:
    """
    This data source provides details about a specific Instance Measured Boot Report resource in Oracle Cloud Infrastructure Core service.

    Gets the measured boot report for this shielded instance.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_instance_measured_boot_report = oci.Core.get_instance_measured_boot_report(instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str instance_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance.
    """
    __args__ = dict()
    __args__['instanceId'] = instance_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getInstanceMeasuredBootReport:getInstanceMeasuredBootReport', __args__, opts=opts, typ=GetInstanceMeasuredBootReportResult).value

    return AwaitableGetInstanceMeasuredBootReportResult(
        id=__ret__.id,
        instance_id=__ret__.instance_id,
        is_policy_verification_successful=__ret__.is_policy_verification_successful,
        measurements=__ret__.measurements)


@_utilities.lift_output_func(get_instance_measured_boot_report)
def get_instance_measured_boot_report_output(instance_id: Optional[pulumi.Input[str]] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstanceMeasuredBootReportResult]:
    """
    This data source provides details about a specific Instance Measured Boot Report resource in Oracle Cloud Infrastructure Core service.

    Gets the measured boot report for this shielded instance.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_instance_measured_boot_report = oci.Core.get_instance_measured_boot_report(instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str instance_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetIdentityProvidersResult',
    'AwaitableGetIdentityProvidersResult',
    'get_identity_providers',
    'get_identity_providers_output',
]

@pulumi.output_type
class GetIdentityProvidersResult:
    """
    A collection of values returned by getIdentityProviders.
    """
    def __init__(__self__, compartment_id=None, filters=None, id=None, identity_providers=None, name=None, protocol=None, state=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identity_providers and not isinstance(identity_providers, list):
            raise TypeError("Expected argument 'identity_providers' to be a list")
        pulumi.set(__self__, "identity_providers", identity_providers)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the tenancy containing the `IdentityProvider`.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetIdentityProvidersFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="identityProviders")
    def identity_providers(self) -> Sequence['outputs.GetIdentityProvidersIdentityProviderResult']:
        """
        The list of identity_providers.
        """
        return pulumi.get(self, "identity_providers")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name you assign to the `IdentityProvider` during creation. The name must be unique across all `IdentityProvider` objects in the tenancy and cannot be changed. This is the name federated users see when choosing which identity provider to use when signing in to the Oracle Cloud Infrastructure Console.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def protocol(self) -> str:
        """
        The protocol used for federation. Allowed value: `SAML2`.  Example: `SAML2`
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state.
        """
        return pulumi.get(self, "state")


class AwaitableGetIdentityProvidersResult(GetIdentityProvidersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdentityProvidersResult(
            compartment_id=self.compartment_id,
            filters=self.filters,
            id=self.id,
            identity_providers=self.identity_providers,
            name=self.name,
            protocol=self.protocol,
            state=self.state)


def get_identity_providers(compartment_id: Optional[str] = None,
                           filters: Optional[Sequence[pulumi.InputType['GetIdentityProvidersFilterArgs']]] = None,
                           name: Optional[str] = None,
                           protocol: Optional[str] = None,
                           state: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdentityProvidersResult:
    """
    This data source provides the list of Identity Providers in Oracle Cloud Infrastructure Identity service.

    **Deprecated.** For more information, see [Deprecated IAM Service APIs](https://docs.cloud.oracle.com/iaas/Content/Identity/Reference/deprecatediamapis.htm).

    Lists all the identity providers in your tenancy. You must specify the identity provider type (e.g., `SAML2` for
    identity providers using the SAML2.0 protocol). You must specify your tenancy's OCID as the value for the
    compartment ID (remember that the tenancy is simply the root compartment).
    See [Where to Get the Tenancy's OCID and User's OCID](https://docs.cloud.oracle.com/iaas/Content/API/Concepts/apisigningkey.htm#five).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_identity_providers = oci.Identity.get_identity_providers(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        protocol=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment (remember that the tenancy is simply the root compartment).
    :param str name: A filter to only return resources that match the given name exactly.
    :param str protocol: The protocol used for federation.
    :param str state: A filter to only return resources that match the given lifecycle state.  The state value is case-insensitive.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    __args__['name'] = name
    __args__['protocol'] = protocol
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Identity/getIdentityProviders:getIdentityProviders', __args__, opts=opts, typ=GetIdentityProvidersResult).value

    return AwaitableGetIdentityProvidersResult(
        compartment_id=__ret__.compartment_id,
        filters=__ret__.filters,
        id=__ret__.id,
        identity_providers=__ret__.identity_providers,
        name=__ret__.name,
        protocol=__ret__.protocol,
        state=__ret__.state)


@_utilities.lift_output_func(get_identity_providers)
def get_identity_providers_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                  filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetIdentityProvidersFilterArgs']]]]] = None,
                                  name: Optional[pulumi.Input[Optional[str]]] = None,
                                  protocol: Optional[pulumi.Input[str]] = None,
                                  state: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetIdentityProvidersResult]:
    """
    This data source provides the list of Identity Providers in Oracle Cloud Infrastructure Identity service.

    **Deprecated.** For more information, see [Deprecated IAM Service APIs](https://docs.cloud.oracle.com/iaas/Content/Identity/Reference/deprecatediamapis.htm).

    Lists all the identity providers in your tenancy. You must specify the identity provider type (e.g., `SAML2` for
    identity providers using the SAML2.0 protocol). You must specify your tenancy's OCID as the value for the
    compartment ID (remember that the tenancy is simply the root compartment).
    See [Where to Get the Tenancy's OCID and User's OCID](https://docs.cloud.oracle.com/iaas/Content/API/Concepts/apisigningkey.htm#five).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_identity_providers = oci.Identity.get_identity_providers(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        protocol=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment (remember that the tenancy is simply the root compartment).
    :param str name: A filter to only return resources that match the given name exactly.
    :param str protocol: The protocol used for federation.
    :param str state: A filter to only return resources that match the given lifecycle state.  The state value is case-insensitive.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetMysqlConfigurationsResult',
    'AwaitableGetMysqlConfigurationsResult',
    'get_mysql_configurations',
    'get_mysql_configurations_output',
]

@pulumi.output_type
class GetMysqlConfigurationsResult:
    """
    A collection of values returned by getMysqlConfigurations.
    """
    def __init__(__self__, compartment_id=None, configuration_id=None, configurations=None, display_name=None, filters=None, id=None, shape_name=None, state=None, types=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if configuration_id and not isinstance(configuration_id, str):
            raise TypeError("Expected argument 'configuration_id' to be a str")
        pulumi.set(__self__, "configuration_id", configuration_id)
        if configurations and not isinstance(configurations, list):
            raise TypeError("Expected argument 'configurations' to be a list")
        pulumi.set(__self__, "configurations", configurations)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if shape_name and not isinstance(shape_name, str):
            raise TypeError("Expected argument 'shape_name' to be a str")
        pulumi.set(__self__, "shape_name", shape_name)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if types and not isinstance(types, list):
            raise TypeError("Expected argument 'types' to be a list")
        pulumi.set(__self__, "types", types)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        OCID of the Compartment the Configuration exists in.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="configurationId")
    def configuration_id(self) -> Optional[str]:
        return pulumi.get(self, "configuration_id")

    @property
    @pulumi.getter
    def configurations(self) -> Sequence['outputs.GetMysqlConfigurationsConfigurationResult']:
        """
        The list of configurations.
        """
        return pulumi.get(self, "configurations")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The display name of the Configuration.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetMysqlConfigurationsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="shapeName")
    def shape_name(self) -> Optional[str]:
        """
        The name of the associated Shape.
        """
        return pulumi.get(self, "shape_name")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the Configuration.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def types(self) -> Optional[Sequence[str]]:
        """
        The Configuration type, DEFAULT or CUSTOM.
        """
        return pulumi.get(self, "types")


class AwaitableGetMysqlConfigurationsResult(GetMysqlConfigurationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMysqlConfigurationsResult(
            compartment_id=self.compartment_id,
            configuration_id=self.configuration_id,
            configurations=self.configurations,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            shape_name=self.shape_name,
            state=self.state,
            types=self.types)


def get_mysql_configurations(compartment_id: Optional[str] = None,
                             configuration_id: Optional[str] = None,
                             display_name: Optional[str] = None,
                             filters: Optional[Sequence[pulumi.InputType['GetMysqlConfigurationsFilterArgs']]] = None,
                             shape_name: Optional[str] = None,
                             state: Optional[str] = None,
                             types: Optional[Sequence[str]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMysqlConfigurationsResult:
    """
    This data source provides the list of Mysql Configurations in Oracle Cloud Infrastructure MySQL Database service.

    Lists the Configurations available when creating a DB System.

    This may include DEFAULT configurations per Shape and CUSTOM configurations.

    The default sort order is a multi-part sort by:
      - shapeName, ascending
      - DEFAULT-before-CUSTOM
      - displayName ascending

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_mysql_configurations = oci.Mysql.get_mysql_configurations(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        configuration_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        shape_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        types=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str configuration_id: The requested Configuration instance.
    :param str display_name: A filter to return only the resource matching the given display name exactly.
    :param str shape_name: The requested Shape name.
    :param str state: Configuration Lifecycle State
    :param Sequence[str] types: The requested Configuration types.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['configurationId'] = configuration_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['shapeName'] = shape_name
    __args__['state'] = state
    __args__['types'] = types
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Mysql/getMysqlConfigurations:getMysqlConfigurations', __args__, opts=opts, typ=GetMysqlConfigurationsResult).value

    return AwaitableGetMysqlConfigurationsResult(
        compartment_id=__ret__.compartment_id,
        configuration_id=__ret__.configuration_id,
        configurations=__ret__.configurations,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        shape_name=__ret__.shape_name,
        state=__ret__.state,
        types=__ret__.types)


@_utilities.lift_output_func(get_mysql_configurations)
def get_mysql_configurations_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                    configuration_id: Optional[pulumi.Input[Optional[str]]] = None,
                                    display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                    filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetMysqlConfigurationsFilterArgs']]]]] = None,
                                    shape_name: Optional[pulumi.Input[Optional[str]]] = None,
                                    state: Optional[pulumi.Input[Optional[str]]] = None,
                                    types: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMysqlConfigurationsResult]:
    """
    This data source provides the list of Mysql Configurations in Oracle Cloud Infrastructure MySQL Database service.

    Lists the Configurations available when creating a DB System.

    This may include DEFAULT configurations per Shape and CUSTOM configurations.

    The default sort order is a multi-part sort by:
      - shapeName, ascending
      - DEFAULT-before-CUSTOM
      - displayName ascending

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_mysql_configurations = oci.Mysql.get_mysql_configurations(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        configuration_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        shape_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        types=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str configuration_id: The requested Configuration instance.
    :param str display_name: A filter to return only the resource matching the given display name exactly.
    :param str shape_name: The requested Shape name.
    :param str state: Configuration Lifecycle State
    :param Sequence[str] types: The requested Configuration types.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetNetworkFirewallsResult',
    'AwaitableGetNetworkFirewallsResult',
    'get_network_firewalls',
    'get_network_firewalls_output',
]

@pulumi.output_type
class GetNetworkFirewallsResult:
    """
    A collection of values returned by getNetworkFirewalls.
    """
    def __init__(__self__, availability_domain=None, compartment_id=None, display_name=None, filters=None, id=None, network_firewall_collections=None, network_firewall_policy_id=None, state=None):
        if availability_domain and not isinstance(availability_domain, str):
            raise TypeError("Expected argument 'availability_domain' to be a str")
        pulumi.set(__self__, "availability_domain", availability_domain)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if network_firewall_collections and not isinstance(network_firewall_collections, list):
            raise TypeError("Expected argument 'network_firewall_collections' to be a list")
        pulumi.set(__self__, "network_firewall_collections", network_firewall_collections)
        if network_firewall_policy_id and not isinstance(network_firewall_policy_id, str):
            raise TypeError("Expected argument 'network_firewall_policy_id' to be a str")
        pulumi.set(__self__, "network_firewall_policy_id", network_firewall_policy_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="availabilityDomain")
    def availability_domain(self) -> Optional[str]:
        """
        Availability Domain where Network Firewall instance is created. To get a list of availability domains for a tenancy, use [ListAvailabilityDomains](https://docs.cloud.oracle.com/iaas/api/#/en/identity/20160918/AvailabilityDomain/ListAvailabilityDomains) operation. Example: `kIdk:PHX-AD-1`
        """
        return pulumi.get(self, "availability_domain")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the Network Firewall.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        A user-friendly name for the Network Firewall. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetNetworkFirewallsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Network Firewall resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="networkFirewallCollections")
    def network_firewall_collections(self) -> Sequence['outputs.GetNetworkFirewallsNetworkFirewallCollectionResult']:
        """
        The list of network_firewall_collection.
        """
        return pulumi.get(self, "network_firewall_collections")

    @property
    @pulumi.getter(name="networkFirewallPolicyId")
    def network_firewall_policy_id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Network Firewall Policy.
        """
        return pulumi.get(self, "network_firewall_policy_id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the Network Firewall.
        """
        return pulumi.get(self, "state")


class AwaitableGetNetworkFirewallsResult(GetNetworkFirewallsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkFirewallsResult(
            availability_domain=self.availability_domain,
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            network_firewall_collections=self.network_firewall_collections,
            network_firewall_policy_id=self.network_firewall_policy_id,
            state=self.state)


def get_network_firewalls(availability_domain: Optional[str] = None,
                          compartment_id: Optional[str] = None,
                          display_name: Optional[str] = None,
                          filters: Optional[Sequence[pulumi.InputType['GetNetworkFirewallsFilterArgs']]] = None,
                          id: Optional[str] = None,
                          network_firewall_policy_id: Optional[str] = None,
                          state: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkFirewallsResult:
    """
    This data source provides the list of Network Firewalls in Oracle Cloud Infrastructure Network Firewall service.

    Returns a list of NetworkFirewalls.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_network_firewalls = oci.NetworkFirewall.get_network_firewalls(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        availability_domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        network_firewall_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str availability_domain: A filter to return only resources that are present within the specified availability domain. To get a list of availability domains for a tenancy, use [ListAvailabilityDomains](https://docs.cloud.oracle.com/iaas/api/#/en/identity/20160918/AvailabilityDomain/ListAvailabilityDomains) operation. Example: `kIdk:PHX-AD-1`
    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Network Firewall resource.
    :param str network_firewall_policy_id: A filter to return only resources that match the entire networkFirewallPolicyId given.
    :param str state: A filter to return only resources with a lifecycleState matching the given value.
    """
    __args__ = dict()
    __args__['availabilityDomain'] = availability_domain
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['networkFirewallPolicyId'] = network_firewall_policy_id
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:NetworkFirewall/getNetworkFirewalls:getNetworkFirewalls', __args__, opts=opts, typ=GetNetworkFirewallsResult).value

    return AwaitableGetNetworkFirewallsResult(
        availability_domain=__ret__.availability_domain,
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        network_firewall_collections=__ret__.network_firewall_collections,
        network_firewall_policy_id=__ret__.network_firewall_policy_id,
        state=__ret__.state)


@_utilities.lift_output_func(get_network_firewalls)
def get_network_firewalls_output(availability_domain: Optional[pulumi.Input[Optional[str]]] = None,
                                 compartment_id: Optional[pulumi.Input[str]] = None,
                                 display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                 filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetNetworkFirewallsFilterArgs']]]]] = None,
                                 id: Optional[pulumi.Input[Optional[str]]] = None,
                                 network_firewall_policy_id: Optional[pulumi.Input[Optional[str]]] = None,
                                 state: Optional[pulumi.Input[Optional[str]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNetworkFirewallsResult]:
    """
    This data source provides the list of Network Firewalls in Oracle Cloud Infrastructure Network Firewall service.

    Returns a list of NetworkFirewalls.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_network_firewalls = oci.NetworkFirewall.get_network_firewalls(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        availability_domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        network_firewall_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str availability_domain: A filter to return only resources that are present within the specified availability domain. To get a list of availability domains for a tenancy, use [ListAvailabilityDomains](https://docs.cloud.oracle.com/iaas/api/#/en/identity/20160918/AvailabilityDomain/ListAvailabilityDomains) operation. Example: `kIdk:PHX-AD-1`
    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Network Firewall resource.
    :param str network_firewall_policy_id: A filter to return only resources that match the entire networkFirewallPolicyId given.
    :param str state: A filter to return only resources with a lifecycleState matching the given value.
    """
    ...
